#ifndef __SENDMSG_H
#define __SENDMSG_H
/*-------------------------------------------------------------------------
 * Copyright (c) 2000-2006 Kenneth W. Sodemann (ken.sodemann@gmail.com)
 *-------------------------------------------------------------------------
 * sendmsg
 *
 * Synopsis:
 *    Procedures used to send out a predefined e-mail message.
 *
 * $Id: sendmsg.h,v 1.11 2007/11/03 23:28:31 stuffle Exp $
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to
 * Free Software Foundation, Inc.
 * 59 Temple Place, Suite 330 
 * Boston, MA  02111-1307  USA
 *-------------------------------------------------------------------------
 */
/*! \file sendmsg.h
   
    \brief Send notification messages to users.

    The funcions contained within are intended for use by the database
    for sending notification messages to the PRepS users.  These 
    functions are called from triggers in the database.

    Note that many of the function parameters are of type \a text.  This 
    is a type defined by PostgreSQL to handle the database \a text type.  
    See the PostgreSQL for details on how to manipulate these types from 
    C code.

    \author Kenneth W. Sodemann (ken.sodemann@gmail.com)
    $Revision: 1.11 $
    $Date: 2007/11/03 23:28:31 $
*/
#include <postgres.h>
#include <fmgr.h>

#ifdef HAVE_CONFIG_H
#  include <config.h>
#endif

/* 
 * __BEGIN_DECLS should be used at the beginning of your declarations,
 * so that C++ compilers don't mangle their names.  Use __END_DECLS at
 * the end of C declarations. 
 */
#undef __BEGIN_DECLS
#undef __END_DECLS
#ifdef __cplusplus
# define __BEGIN_DECLS extern "C" {
# define __END_DECLS }
#else
# define __BEGIN_DECLS /* empty */
# define __END_DECLS /* empty */
#endif

/* 
 * __P is a macro used to wrap function prototypes, so that compilers
 * that don't understand ANSI C prototypes still work, and ANSI C
 * compilers can issue warnings about type mismatches. 
 */
#undef __P
#if defined (__STDC__) || defined (_AIX) \
        || (defined (__mips) && defined (_SYSTYPE_SVR4)) \
                || defined(WIN32) || defined(__cplusplus)
# define __P(protos) protos
#else
# define __P(protos) ()
#endif

__BEGIN_DECLS
/*! \fn send_new_pr_msg (const text *email_list,
                         const text *project,
                         const text *pr_title,
                         const text *descr,
                         const text *severity,
                         const text *problem_type,
                         const text *submitter)
 
 \brief Format and send a 'new problem report' notification message.

 Use the file \$PREFIX/share/preps/new_pr.msg as a template to create
 a 'new problem report' notification message.  Send the message out
 to the recipient list.

 \param email_list
 The white space separated recipient list for the notification message.
 \param project
 The name of the project that the problem report was entered against.
 \param pr_title
 The title (or 'subject') of the problem report.
 \param descr
 The detailed description of the problem report.
 \param severity
 The textual description of the severity of the problem report.
 \param problem_type
 The textual description of the type of problem.
 \param submitter
 The name of the submitter.

 \return Always returns zero.
*/
int4 send_new_pr_msg __P((const text *email_list,
                          const text *project,
                          const text *pr_title,
                          const text *descr,
                          const text *severity,
                          const text *problem_type,
                          const text *submitter));

/*! send_assign_msg (const text *email_list,
                     const text *pr_title,
                     const text *descr,
                     const text *fix_descr,
                     const text *status,
                     const text *severity,
                     const text *responsible,
                     const text *submitter)

 \brief Format and send an 'assignment' notification message.

 Use the file \$PREFIX/share/preps/assign.msg as a template to create
 an 'assignment' notification message.  Send the message out to the
 recipient list.

 \param email_list
 The white space separated recipient list for the notification message.
 \param pr_title
 The title (or 'subject') of the problem report.
 \param descr
 The detailed description of the problem report.
 \param fix_descr
 The detailed description of the fix for the problem report.
 \param status
 The textual description of the status of the problem report.
 \param severity
 The textual description of the severity of the problem report.
 \param responsible
 The name of the assignee.
 \param submitter
 The name of the submitter.

 \return Always returns zero.
*/
int4 send_assign_msg __P((const text *email_list,
                          const text *pr_title,
                          const text *descr,
                          const text *fix_descr,
                          const text *status,
                          const text *severity,
                          const text *responsible,
                          const text *submitter));

/*! \fn send_update_msg (const text *email_list,
                           const text *pr_title,
                           const text *descr,
                           const text *fix_descr,
                           const text *status,
                           const text *severity,
                           const text *responsible,
                           const text *submitter)

 \brief Format and send an 'update' notification message.

 Use the file \$PREFIX/share/preps/update.msg as a template to create
 an 'update' notification message.  Send the message out to the
 recipient list.

 \param email_list
 The white space separated recipient list for the notification message.
 \param pr_title
 The title (or 'subject') of the problem report.
 \param descr
 The detailed description of the problem report.
 \param fix_descr
 The detailed description of the fix for the problem report.
 \param status
 The textual description of the status of the problem report.
 \param severity
 The textual description of the severity of the problem report.
 \param responsible
 The name of the assignee.
 \param submitter
 The name of the submitter.

 \return Always returns zero.
*/
int4 send_update_msg __P((const text *email_list,
                           const text *pr_title,
                           const text *descr,
                           const text *fix_descr,
                           const text *status,
                           const text *severity,
                           const text *responsible,
                           const text *submitter));
__END_DECLS

#endif
